Struct binarystream::binary::ZigZag
source · pub struct ZigZag {}Expand description
- ZigZag
- Represents a 32 bit ( 4 bytes ) zigzag encoded signed variable length integer. ( -2147483648 to 2147483647 )
Implementations
sourceimpl ZigZag
impl ZigZag
pub fn into_reference(val: ZigZag, env: Env) -> Result<Reference<ZigZag>>
pub fn into_instance(self, env: Env) -> Result<ClassInstance<ZigZag>>
sourceimpl ZigZag
impl ZigZag
sourcepub fn read(stream: &mut BinaryStream) -> Result<i32>
pub fn read(stream: &mut BinaryStream) -> Result<i32>
- read
- Reads a 32 bit ( 4 bytes ) zigzag encoded signed variable length integer from the stream. ( -2147483648 to 2147483647 )
sourcepub fn write(stream: &mut BinaryStream, value: i32)
pub fn write(stream: &mut BinaryStream, value: i32)
- write
- Writes a 32 bit ( 4 bytes ) zigzag encoded signed variable length integer to the stream. ( -2147483648 to 2147483647 )